aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/cache.php
diff options
context:
space:
mode:
authorCash Costello <cash.costello@gmail.com>2012-01-21 12:44:55 -0500
committerCash Costello <cash.costello@gmail.com>2012-01-21 12:44:55 -0500
commit19a6962c819dc33a0967dcef56154f6930b52287 (patch)
treef81d3530358a4056caf12a695d0700b0c232a69d /engine/lib/cache.php
parent8e4d4c50df3f19be4ad9c204797e57ecd9ba02b3 (diff)
downloadelgg-19a6962c819dc33a0967dcef56154f6930b52287.tar.gz
elgg-19a6962c819dc33a0967dcef56154f6930b52287.tar.bz2
Fixes #4180 finished conversion to system cache by converting datalist/CONFIG var name
Diffstat (limited to 'engine/lib/cache.php')
-rw-r--r--engine/lib/cache.php16
1 files changed, 8 insertions, 8 deletions
diff --git a/engine/lib/cache.php b/engine/lib/cache.php
index b563f5ab0..75183d23a 100644
--- a/engine/lib/cache.php
+++ b/engine/lib/cache.php
@@ -54,7 +54,7 @@ function elgg_reset_system_cache() {
function elgg_save_system_cache($type, $data) {
global $CONFIG;
- if ($CONFIG->viewpath_cache_enabled) {
+ if ($CONFIG->system_cache_enabled) {
$cache = elgg_get_system_cache();
return $cache->save($type, $data);
}
@@ -71,7 +71,7 @@ function elgg_save_system_cache($type, $data) {
function elgg_load_system_cache($type) {
global $CONFIG;
- if ($CONFIG->viewpath_cache_enabled) {
+ if ($CONFIG->system_cache_enabled) {
$cache = elgg_get_system_cache();
$cached_data = $cache->load($type);
@@ -86,7 +86,7 @@ function elgg_load_system_cache($type) {
/**
* Enables the system disk cache.
*
* Uses the 'viewpath_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*
* @return void
@@ -94,15 +94,15 @@ function elgg_load_system_cache($type) {
function elgg_enable_system_cache() {
global $CONFIG;
- datalist_set('viewpath_cache_enabled', 1);
- $CONFIG->viewpath_cache_enabled = 1;
+ datalist_set('system_cache_enabled', 1);
+ $CONFIG->system_cache_enabled = 1;
elgg_reset_system_cache();
}
/**
* Disables the system disk cache.
*
* Uses the 'viewpath_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*
* @return void
@@ -110,8 +110,8 @@ function elgg_enable_system_cache() {
function elgg_disable_system_cache() {
global $CONFIG;
- datalist_set('viewpath_cache_enabled', 0);
- $CONFIG->viewpath_cache_enabled = 0;
+ datalist_set('system_cache_enabled', 0);
+ $CONFIG->system_cache_enabled = 0;
elgg_reset_system_cache();
}
@@ -86,7 +86,7 @@ function elgg_load_system_cache($type) {
* Enables the system disk cache.
*
- * Uses the 'viewpath_cache_enabled' datalist with a boolean value.
+ * Uses the 'system_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*
@@ -94,15 +94,15 @@ function elgg_load_system_cache($type) {
* Disables the system disk cache.
*
- * Uses the 'viewpath_cache_enabled' datalist with a boolean value.
+ * Uses the 'system_cache_enabled' datalist with a boolean value.
* Resets the system cache.
*